from setuptools import setup

setup(
    name='timeliterals',
    packages=[
        'timeliterals',
    ],
    author='pgdr',
    version='0.0.1',
    author_email='pgdr@equinor.com',
    description="Time literals",
    test_suite="tests",
)
